@@ -1,5 +1,6 @@
 from frost.server.server import FrostServer
-from frost.server.headers import Header, Method
+from frost.server.socketio import threaded
+from frost.server.headers import Header, Method, Status
 from frost.server.auth import auth_required
 from frost.server.logger import logger
 
@@ -7,6 +8,8 @@ __all__ = (
     'FrostServer',
     'Header',
     'Method',
+    'Status',
+    'threaded',
     'auth_required',
     'logger'
 )
