@@ -3,6 +3,7 @@ from functools import wraps
 
 from frost.server.headers import Header
 from frost.server.storage import User
+from frost.server.headers import Status
 
 
 def auth_required(func: Callable) -> Callable:
@@ -17,8 +18,8 @@ def auth_required(func: Callable) -> Callable:
     """
     @wraps(func)
     def execute(*args, **kwargs):
-        id_ = args[0]['headers'].get(Header.ID_TOKEN.value)
-        token = args[0]['headers'].get(Header.AUTH_TOKEN.value)
+        id_ = args[1]['headers'].get(Header.ID_TOKEN.value)
+        token = args[1]['headers'].get(Header.AUTH_TOKEN.value)
 
         if id_ is not None and token is not None:
             user = User.search(id_)
@@ -26,4 +27,6 @@ def auth_required(func: Callable) -> Callable:
             if user is not None and user['token'] == token:
                 return func(*args, **kwargs, id_=id_, token=token)
 
+        return Status.INVALID_AUTH
+
     return execute
